@@ -9,16 +9,21 @@ HERE = os.path.abspath(os.path.dirname(__file__))
 config = {
     "set": {
         "OPENEDX_AWS_ACCESS_KEY": "openedx",
-        "OPENEDX_AWS_SECRET_ACCESS_KEY": "{{ 24|random_string }}",
+        "OPENEDX_AWS_SECRET_ACCESS_KEY": "{{ MINIO_AWS_SECRET_ACCESS_KEY }}",
+    },
+    "add": {
+        "AWS_SECRET_ACCESS_KEY": "{{ 24|random_string }}",
     },
     "defaults": {
         "VERSION": __version__,
         "BUCKET_NAME": "openedx",
         "FILE_UPLOAD_BUCKET_NAME": "openedxuploads",
         "VIDEO_UPLOAD_BUCKET_NAME": "openedxvideos",
-        "HOST": "minio.{{ LMS_HOST }}",
-        "DOCKER_REGISTRY": "{{ DOCKER_REGISTRY }}",
-        "DOCKER_IMAGE": "overhangio/minio:{{ MINIO_VERSION }}",
+        "HOST": "files.{{ LMS_HOST }}",
+        "CONSOLE_HOST": "minio.{{ LMS_HOST }}",
+        "DOCKER_IMAGE": "docker.io/minio/minio:RELEASE.2021-11-09T03-21-45Z",
+        "MC_DOCKER_IMAGE": "docker.io/minio/mc:RELEASE.2021-11-16T20-37-36Z",
+        "GATEWAY": None,
     },
 }
 
@@ -26,8 +31,6 @@ templates = os.path.join(HERE, "templates")
 
 hooks = {
     "pre-init": ["minio"],
-    "build-image": {"minio": "{{ DOCKER_REGISTRY }}{{ MINIO_DOCKER_IMAGE }}"},
-    "remote-image": {"minio": "{{ DOCKER_REGISTRY }}{{ MINIO_DOCKER_IMAGE }}"},
 }
 
 
